<?php

namespace Controller;

use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Util\InstanceProvider;
use Util\Utilities;

class ProductVersion
{
    public function findProductVersion(Request\Filter $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $page = $request->getFilterCriteria()->getPage();
        $pageSize = $request->getFilterCriteria()->getPageSize();
        try {
            $versions = InstanceProvider::getService()->getProductVersion()->findProductVersion($conditions, $page, $pageSize);
            $response->addDataSet(new DataSet('findProductVersion', $versions));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
     public function removeLTSFromVersions(DTO\Request\Dataset $request, DTO\Response $response) {
        try {
            InstanceProvider::getService()->getProductVersion()->removeLTSFromVersions($request->getDataSet()->getRows());
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function findLTSProductVersionToRemove(Request\Filter $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $projects = Utilities::getValueInFilterDataSourceByName($conditions,'PROJECTS');
        try {
            $versions = InstanceProvider::getService()->getProductVersion()->findLTSProductVersionToRemove($projects);
            $response->addDataSet(new DataSet('findLTSProductVersionToRemove', $versions));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    

    public function findProductVersionLtsWithoutBuild(Request\Filter $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $page = $request->getFilterCriteria()->getPage();
        $pageSize = $request->getFilterCriteria()->getPageSize();
        try {
            $versions = InstanceProvider::getService()->getProductVersion()->findProductVersionLtsWithoutBuild($conditions, $page, $pageSize);
            $response->addDataSet(new DataSet('findProductVersionLtsWithoutBuild', $versions));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findLtsCurrentProductVersionFromVersion(Request\Filter $request, Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $version = InstanceProvider::getService()->getProductVersion()->findLtsCurrentProductVersionFromVersion($conditions);
            $response->addDataSet(new DataSet('findLtsCurrentProductVersionFromVersion', $version));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findProductVersionLtsByProject(Request\Filter $request, Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $version = InstanceProvider::getService()->getProductVersion()->findProductVersionLtsByProject($conditions);
            $response->addDataSet(new DataSet('findProductVersionLtsByProject', $version));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function findNextLTSFromVersion(Request\Filter $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $page       = $request->getFilterCriteria()->getPage();
        $pageSize   = $request->getFilterCriteria()->getPageSize();
        try {
            $version = InstanceProvider::getService()->getProductVersion()->findNextLTSFromVersion($conditions, $page, $pageSize);
            $response->addDataSet(new DataSet('findNextLTSFromVersion', $version));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
}