
/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/* Nome: 0004_CARSTPO_USR_EXPORTAAF_COMPASSARGENTINA.sql                      */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a possibilitar que as autorizaes de fornecimento     */
/* (AF's) geradas pelo sistema da Teknisa sejam importadas no sistema do      */
/* Portal e, para isso, a procedure alimentar duas tabelas intermedirias    */
/* entre os dois sistemas                                                     */
/* (tabelas pertencentes ao banco de dados do sistema da Teknisa).            */
/* Criao:                                                                   */
/* 23/01/2012 - Marcelo Alexsandro                                            */
/******************************************************************************/



CREATE OR REPLACE PROCEDURE USR_EXPORTAAF IS
/* 19/02/2013 - Marcelo Alexsandro                                            */
   V_DTGRV           DATE;
   V_HRGRV           VARCHAR2(04);
   V_CONTFORN        VARCHAR(30);
   V_DESC1           FLOAT;
   V_DESC2           FLOAT;
   V_NRSEQ           VARCHAR(4);
   V_VRRETSEGSOCIAL  FLOAT;
   V_NOVOCODIGO      INTEGER;
   V_NRSEQUENCIAL    INTEGER;
   V_PRXCODIGO       VARCHAR2(20);
   V_VRIVAMP         FLOAT;
   V_VRIMPINT02      FLOAT;
   V_VRPIBBA         FLOAT;
   V_VRPERCIVA       FLOAT;
   V_VRABASTOS       FLOAT;
   V_VRPIBCP         FLOAT;
   V_VRPIBCBA        FLOAT;
   V_VRPIBSFE        FLOAT;
   V_VRPIBMZA        FLOAT;
   V_VRPIBSJ         FLOAT;
   V_VRPIBCAT        FLOAT;
   V_VRPIBTUC        FLOAT;
   V_VRPIBCTE        FLOAT;
   V_VRPIBSAL        FLOAT;
   V_VRPIBSL         FLOAT;
   V_VRPIBTF         FLOAT;
   V_VRIVAOC         FLOAT;
   V_VRIVA19         FLOAT;
   V_VRIVA20         FLOAT;
   V_VRIMPINT21      FLOAT;
   V_VRPIBMIS        FLOAT;
   V_VRPIIBBTUC      FLOAT;
   V_CDSOLPORTAL     VARCHAR2(20);
   V_NRSOLPORTAL     INTEGER;
   V_NRITEMSOLPORTAL INTEGER;
   V_NRSOLTEKNISA    VARCHAR2(10);
   V_RETURN          VARCHAR2(1);
   V_ERROR VARCHAR2(4000);
BEGIN
   V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_AUTOFORNE%USR_INT_ITEMAUTF', 'B');
   IF V_RETURN = 'S' THEN
      V_DTGRV := NULL;
      V_HRGRV := NULL;

      V_NRSEQ := '0001';

      /* Retorna data e hora de exportac?o */
      BEGIN
        SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
          INTO V_DTGRV, V_HRGRV
          FROM DUAL;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
           V_DTGRV := NULL;
           V_HRGRV := NULL;
      END;

      FOR C_AFEXPORT IN
        (SELECT A.CDFILDEST, A.CDFILLANC, A.NRAUTOFORN,
                A.DTAUTOFORN, A.CDFORNECED, A.VRTOTALAF,
                A.CDFORMPGTO, A.CDEMPRESA, A.IDAFFORALIM,
                A.CDGERENTE, A.IDAUTOFORNEX, A.IDTIPOLANCAF,
                A.IDSITUATUAAF, DECODE(USR_NRSEQUENCIAL, NULL, '1', '4') IDMOTIVOENVIO,
                A.USR_IDAFREVISADA, A.CDOPERADOR, A.USR_CDAFPORTAL , A.USR_NRAFPORTAL
           FROM AUTOFORNE A, FORNECEDOR F
          WHERE A.USR_DTEXPORTA IS NULL
            AND A.CDFORNECED = F.CDFORNECED
            AND A.IDAFFORALIM = 'N'
            AND A.IDSITUATUAAF IS NULL
            AND A.IDBAIXAAF IS NULL
            AND EXISTS (SELECT 1
                          FROM GRUPFILI, FILGRUPFILI
                         WHERE GRUPFILI.CDGRUPFILI = FILGRUPFILI.CDGRUPFILI
                           AND GRUPFILI.CDGRUPFILI = '9999999999'
                           AND FILGRUPFILI.CDFILIAL = A.CDFILDEST)
         UNION ALL
         SELECT A.CDFILDEST, A.CDFILLANC, A.NRAUTOFORN,
                A.DTAUTOFORN, A.CDFORNECED, A.VRTOTALAF,
                A.CDFORMPGTO, A.CDEMPRESA, A.IDAFFORALIM,
                A.CDGERENTE, A.IDAUTOFORNEX, A.IDTIPOLANCAF,
                A.IDSITUATUAAF, DECODE(A.USR_AFIMPORTADA, 'S', '3', '2') IDMOTIVOENVIO,
                A.USR_IDAFREVISADA, A.CDOPERADOR, A.USR_CDAFPORTAL , A.USR_NRAFPORTAL
           FROM AUTOFORNE A, FORNECEDOR F
          WHERE A.USR_DTEXPORTA IS NULL
            AND A.CDFORNECED = F.CDFORNECED
            AND A.IDAFFORALIM = 'S'
            AND A.IDSITUATUAAF IS NULL
            AND EXISTS (SELECT 1
                          FROM GRUPFILI, FILGRUPFILI
                         WHERE GRUPFILI.CDGRUPFILI = FILGRUPFILI.CDGRUPFILI
                           AND GRUPFILI.CDGRUPFILI = '9999999999'
                           AND FILGRUPFILI.CDFILIAL = A.CDFILDEST)
          ORDER BY CDFILDEST, CDFILLANC, NRAUTOFORN
         )
      LOOP
        FECHAMENTO_AF(C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN);
        BEGIN
           SELECT NMCONTFORN
             INTO V_CONTFORN
             FROM ENDEFORN
            WHERE CDFORNECED = C_AFEXPORT.CDFORNECED
              AND IDTPENDEFORN = 'P';
        EXCEPTION
           WHEN NO_DATA_FOUND THEN
              V_CONTFORN := NULL;
        END;

        SELECT SUM(VRDESCITMAF)
          INTO V_DESC1
          FROM ITEMAUTF
         WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
           AND IDBAIXITMAF IS NULL;

        SELECT SUM(VRENCARGOAF)
          INTO V_DESC2
          FROM ENCARGOAF
         WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
           AND CDENCARGO = '01';

        SELECT SUM(VRENCARGOAF)
          INTO V_VRRETSEGSOCIAL
          FROM ENCARGOAF
         WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
           AND CDENCARGO = '10';

        /* Verifica existencia da AF */
        SELECT MAX(NRSEQUENCIAL)
          INTO V_NRSEQUENCIAL
          FROM USR_INT_AUTOFORNE
         WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
           AND IDTPEXPITSOL = '1'
           AND IDORIGREGISTRO = 'T';

        /* Retorna o sequencial para a tabela */
        NOVO_CODIGO('USR_INT_AUTOFORNE', V_PRXCODIGO);
        V_NOVOCODIGO := TO_NUMBER(SUBSTR(V_PRXCODIGO,11,10));

        /* Se nao possui a AF sera incluido um novo registro */
        IF V_NRSEQUENCIAL IS NULL THEN
           INSERT INTO USR_INT_AUTOFORNE(
              NRSEQUENCIAL, CDFILDEST, CDFILLANC, NRAUTOFORN,
              CDEMPRESA, DTAUTOFORN, CDFORNECED, NMCONTFORN,
              CDFORMPGTO, VRDESCONTO1, VRDESCONTO2, VRRETSEGSOCIAL,
              VRTOTALAF, IDTPEXPITSOL, IDORIGREGISTRO, DTGRAVACAO,
              HRGRAVACAO, DTIMPORTACAO, HRIMPORTACAO,
              IDSITUATUAAF, IDAFFORALIM, IDAFREVISADA, CDGERENTE,
              IDMOTIVOENVIO, IDAUTOFORNEX,
              IDTIPOLANCAF, CDOPERADOR, CDAFPORTAL , NRAFPORTAL)
           VALUES
              (V_NOVOCODIGO, C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN,
               C_AFEXPORT.CDEMPRESA, C_AFEXPORT.DTAUTOFORN, C_AFEXPORT.CDFORNECED, V_CONTFORN,
               C_AFEXPORT.CDFORMPGTO, V_DESC1, V_DESC2, V_VRRETSEGSOCIAL,
               C_AFEXPORT.VRTOTALAF, '1', 'T', NULL,
               NULL, NULL, NULL,
               C_AFEXPORT.IDSITUATUAAF, C_AFEXPORT.IDAFFORALIM, C_AFEXPORT.USR_IDAFREVISADA, C_AFEXPORT.CDGERENTE,
               C_AFEXPORT.IDMOTIVOENVIO, C_AFEXPORT.IDAUTOFORNEX,
               C_AFEXPORT.IDTIPOLANCAF, C_AFEXPORT.CDOPERADOR, C_AFEXPORT.USR_CDAFPORTAL , C_AFEXPORT.USR_NRAFPORTAL);
        ELSE
           INSERT INTO USR_INT_AUTOFORNE(
              NRSEQUENCIAL, CDFILDEST, CDFILLANC, NRAUTOFORN,
              CDEMPRESA, DTAUTOFORN, CDFORNECED, NMCONTFORN,
              CDFORMPGTO, VRDESCONTO1, VRDESCONTO2, VRRETSEGSOCIAL,
              VRTOTALAF, IDTPEXPITSOL, IDORIGREGISTRO, DTGRAVACAO,
              HRGRAVACAO, DTIMPORTACAO, HRIMPORTACAO,
              IDSITUATUAAF, IDAFFORALIM, IDAFREVISADA, CDGERENTE,
              IDMOTIVOENVIO, IDAUTOFORNEX,
              IDTIPOLANCAF,
              CDOPERADOR, CDAFPORTAL , NRAFPORTAL)
           VALUES
              (V_NOVOCODIGO, C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN,
               C_AFEXPORT.CDEMPRESA, C_AFEXPORT.DTAUTOFORN, C_AFEXPORT.CDFORNECED, V_CONTFORN,
               C_AFEXPORT.CDFORMPGTO, V_DESC1, V_DESC2, V_VRRETSEGSOCIAL,
               C_AFEXPORT.VRTOTALAF, '2', 'T', NULL,
               NULL, NULL, NULL,
               C_AFEXPORT.IDSITUATUAAF, C_AFEXPORT.IDAFFORALIM, C_AFEXPORT.USR_IDAFREVISADA, C_AFEXPORT.CDGERENTE,
               C_AFEXPORT.IDMOTIVOENVIO, C_AFEXPORT.IDAUTOFORNEX,
               C_AFEXPORT.IDTIPOLANCAF,
               C_AFEXPORT.CDOPERADOR, C_AFEXPORT.USR_CDAFPORTAL , C_AFEXPORT.USR_NRAFPORTAL);

           FOR C_ITEXCL IN
              (SELECT
                  NRSEQUENCIAL,NRSEQITEM,CDFILDEST,CDFILLANC,NRAUTOFORN,
                  CDMARCA,CDPRODUTO,DTPROGENTAF,NMPRODUTO,VRQTDEAF,VRPRECOUNIT,
                  VRTOTALITEM,VRIVAMP,VRIMPINT02,VRPIBBA,VRPERCIVA,
                  VRABASTOS,VRPIBCP,VRPIBCBA,VRPIBSFE,VRPIBMZA,VRPIBSJ,VRPIBCAT,
                  VRPIBTUC,VRPIBCTE,VRPIBSAL,VRPIBSL,VRPIBTF,VRIVAOC,VRIVA19,VRIVA20,
                  VRIMPINT21,VRPIBMIS,VRPIIBBTUC,TXOBSITMAF,IDTPEXPITSOL,IDORIGREGISTRO,
                  DTGRAVACAO,HRGRAVACAO,DTIMPORTACAO,HRIMPORTACAO, CDSOLPORTAL, NRSOLPORTAL, NRITEMSOLPORTAL, NRSOLTEKNISA,
                  CDAFPORTAL, NRAFPORTAL, NRITAFPORTAL
                 FROM USR_INT_ITEMAUTF
                WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                  AND CDFILLANC = C_AFEXPORT.CDFILLANC
                  AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                  AND NRSEQUENCIAL = V_NRSEQUENCIAL
                  AND IDTPEXPITSOL = '1'
                  AND IDORIGREGISTRO = 'T'
                ORDER BY CDMARCA, CDPRODUTO, DTPROGENTAF)
           LOOP
              INSERT INTO USR_INT_ITEMAUTF
                 (NRSEQUENCIAL,NRSEQITEM,CDFILDEST,CDFILLANC,NRAUTOFORN,
                  CDMARCA,CDPRODUTO,DTPROGENTAF,NMPRODUTO,VRQTDEAF,VRPRECOUNIT,
                  VRTOTALITEM,VRIVAMP,VRIMPINT02,VRPIBBA,VRPERCIVA,
                  VRABASTOS,VRPIBCP,VRPIBCBA,VRPIBSFE,VRPIBMZA,VRPIBSJ,VRPIBCAT,
                  VRPIBTUC,VRPIBCTE,VRPIBSAL,VRPIBSL,VRPIBTF,VRIVAOC,VRIVA19,VRIVA20,
                  VRIMPINT21,VRPIBMIS,VRPIIBBTUC,TXOBSITMAF,IDTPEXPITSOL,IDORIGREGISTRO,
                  DTGRAVACAO,HRGRAVACAO,DTIMPORTACAO,HRIMPORTACAO, CDSOLPORTAL, NRSOLPORTAL, NRITEMSOLPORTAL, NRSOLTEKNISA,
                  CDAFPORTAL, NRAFPORTAL, NRITAFPORTAL)
              VALUES
                 (V_NOVOCODIGO,C_ITEXCL.NRSEQITEM,C_AFEXPORT.CDFILDEST,C_AFEXPORT.CDFILLANC,C_AFEXPORT.NRAUTOFORN,
                  C_ITEXCL.CDMARCA,C_ITEXCL.CDPRODUTO, C_ITEXCL.DTPROGENTAF,C_ITEXCL.NMPRODUTO,C_ITEXCL.VRQTDEAF, C_ITEXCL.VRPRECOUNIT,
                  C_ITEXCL.VRTOTALITEM,C_ITEXCL.VRIVAMP,C_ITEXCL.VRIMPINT02,C_ITEXCL.VRPIBBA,C_ITEXCL.VRPERCIVA,
                  C_ITEXCL.VRABASTOS,C_ITEXCL.VRPIBCP,C_ITEXCL.VRPIBCBA,C_ITEXCL.VRPIBSFE,C_ITEXCL.VRPIBMZA,C_ITEXCL.VRPIBSJ,C_ITEXCL.VRPIBCAT,
                  C_ITEXCL.VRPIBTUC,C_ITEXCL.VRPIBCTE,C_ITEXCL.VRPIBSAL,C_ITEXCL.VRPIBSL,C_ITEXCL.VRPIBTF,C_ITEXCL.VRIVAOC,C_ITEXCL.VRIVA19,C_ITEXCL.VRIVA20,
                  C_ITEXCL.VRIMPINT21,C_ITEXCL.VRPIBMIS,C_ITEXCL.VRPIIBBTUC,C_ITEXCL.TXOBSITMAF,'2','T',
                  NULL,NULL, NULL, NULL, C_ITEXCL.CDSOLPORTAL, C_ITEXCL.NRSOLPORTAL, C_ITEXCL.NRITEMSOLPORTAL, C_ITEXCL.NRSOLTEKNISA,
                  C_ITEXCL.CDAFPORTAL, C_ITEXCL.NRAFPORTAL, C_ITEXCL.NRITAFPORTAL);
           END LOOP;

           UPDATE USR_INT_ITEMAUTF
             SET DTGRAVACAO = V_DTGRV,
                 HRGRAVACAO = V_HRGRV
           WHERE NRSEQUENCIAL = V_NOVOCODIGO;

           UPDATE USR_INT_AUTOFORNE
             SET DTGRAVACAO = V_DTGRV,
                 HRGRAVACAO = V_HRGRV
           WHERE NRSEQUENCIAL = V_NOVOCODIGO;

           /* Retorna o sequencial para a tabela */
           NOVO_CODIGO('USR_INT_AUTOFORNE', V_PRXCODIGO);
           V_NOVOCODIGO := TO_NUMBER(SUBSTR(V_PRXCODIGO,11,10));

           INSERT INTO USR_INT_AUTOFORNE(
              NRSEQUENCIAL, CDFILDEST, CDFILLANC, NRAUTOFORN,
              CDEMPRESA, DTAUTOFORN, CDFORNECED, NMCONTFORN,
              CDFORMPGTO, VRDESCONTO1, VRDESCONTO2, VRRETSEGSOCIAL,
              VRTOTALAF, IDTPEXPITSOL, IDORIGREGISTRO, DTGRAVACAO,
              HRGRAVACAO, DTIMPORTACAO, HRIMPORTACAO,
              IDSITUATUAAF, IDAFFORALIM, IDAFREVISADA, CDGERENTE,
              IDMOTIVOENVIO, IDAUTOFORNEX,
              IDTIPOLANCAF,
              CDOPERADOR, CDAFPORTAL, NRAFPORTAL)
           VALUES
              (V_NOVOCODIGO, C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN,
               C_AFEXPORT.CDEMPRESA, C_AFEXPORT.DTAUTOFORN, C_AFEXPORT.CDFORNECED, V_CONTFORN,
               C_AFEXPORT.CDFORMPGTO, V_DESC1, V_DESC2, V_VRRETSEGSOCIAL,
               C_AFEXPORT.VRTOTALAF, '1', 'T', NULL,
               NULL, NULL, NULL,
               C_AFEXPORT.IDSITUATUAAF, C_AFEXPORT.IDAFFORALIM, C_AFEXPORT.USR_IDAFREVISADA, C_AFEXPORT.CDGERENTE,
               C_AFEXPORT.IDMOTIVOENVIO, C_AFEXPORT.IDAUTOFORNEX,
               C_AFEXPORT.IDTIPOLANCAF,
               C_AFEXPORT.CDOPERADOR, C_AFEXPORT.USR_CDAFPORTAL, C_AFEXPORT.USR_NRAFPORTAL);
        END IF;

        FOR C_ITEMAUTF IN
           (SELECT ITEMAUTF.CDPRODUTO, PRODUTO.CDARVPROD, ITEMAUTF.CDMARCA, ITEMAUTF.DTPROGENTAF,
                   ITEMAUTF.QTPROGENTAF VRQTDEAF, ITEMAUTF.VRPREUNIAF VRPRECOUNIT, ITEMAUTF.DTENTRITMSOL,
                   ITEMAUTF.TXOBSITMAF, PRODUTO.NMPRODUTO, PRODUTO.CDPRODESTO, ITEMAUTF.USR_CDAFPORTAL, ITEMAUTF.USR_NRAFPORTAL, ITEMAUTF.USR_NRITAFPORTAL
              FROM ITEMAUTF, PRODUTO
             WHERE ITEMAUTF.CDFILDEST = C_AFEXPORT.CDFILDEST
               AND ITEMAUTF.CDFILLANC = C_AFEXPORT.CDFILLANC
               AND ITEMAUTF.NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
               AND ITEMAUTF.IDBAIXITMAF IS NULL
               AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO
             ORDER BY ITEMAUTF.CDMARCA, PRODUTO.CDARVPROD, ITEMAUTF.DTPROGENTAF
           )
        LOOP
           BEGIN
              SELECT MAX(USR_CDORIGEMPORTAL),
                     MAX(USR_NRORIGEMPORTAL),
                     MAX(USR_NRITEMPORTAL),
                     MAX(NRSOLICMP)
                INTO V_CDSOLPORTAL,
                     V_NRSOLPORTAL,
                     V_NRITEMSOLPORTAL,
                     V_NRSOLTEKNISA
                FROM ITEMSOLI, PRODUTO
               WHERE PRODUTO.CDPRODUTO = ITEMSOLI.CDPRODUTO
                 AND PRODUTO.CDPRODESTO = C_ITEMAUTF.CDPRODESTO
                 AND ITEMSOLI.DTPROGENTR = C_ITEMAUTF.DTENTRITMSOL
                 AND ITEMSOLI.CDFILSOLI = C_AFEXPORT.CDFILDEST;
           EXCEPTION
              WHEN NO_DATA_FOUND THEN BEGIN
                 V_NRSOLPORTAL     := NULL;
                 V_NRSOLTEKNISA    := NULL;
                 V_CDSOLPORTAL     := NULL;
                 V_NRITEMSOLPORTAL := NULL;
              END;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRIVAMP
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '01';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRIVAMP := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRIMPINT02
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '02';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRIMPINT02 := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBBA
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '03';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBBA := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPERCIVA
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '04';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPERCIVA := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRABASTOS
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '05';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRABASTOS := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBCP
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '07';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBCP := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBCBA
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '08';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBCBA := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBSFE
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '09';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBSFE := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBMZA
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '10';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBMZA := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBSJ
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '11';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBSJ := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBCAT
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '12';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBCAT := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBTUC
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '13';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBTUC := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBCTE
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '14';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBCTE := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBSAL
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '15';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBSAL := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBSL
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '16';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBSL := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBTF
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '17';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBTF := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRIVAOC
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '18';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRIVAOC := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRIVA19
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '19';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRIVA19 := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRIVA20
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '20';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRIVA20 := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRIMPINT21
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '21';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRIMPINT21 := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIBMIS
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '22';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIBMIS := 0;
           END;

           BEGIN
              SELECT VRALIQITMAF
                INTO V_VRPIIBBTUC
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
                 AND CDIMPOSTO = '23';
           EXCEPTION
              WHEN NO_DATA_FOUND THEN
                 V_VRPIIBBTUC := 0;
           END;

           INSERT INTO USR_INT_ITEMAUTF
              (NRSEQUENCIAL,NRSEQITEM,CDFILDEST,CDFILLANC,NRAUTOFORN,
               CDMARCA,CDPRODUTO,DTPROGENTAF,NMPRODUTO,VRQTDEAF,VRPRECOUNIT,
               VRTOTALITEM,VRIVAMP,VRIMPINT02,VRPIBBA,VRPERCIVA,
               VRABASTOS,VRPIBCP,VRPIBCBA,VRPIBSFE,VRPIBMZA,VRPIBSJ,VRPIBCAT,
               VRPIBTUC,VRPIBCTE,VRPIBSAL,VRPIBSL,VRPIBTF,VRIVAOC,VRIVA19,VRIVA20,
               VRIMPINT21,VRPIBMIS,VRPIIBBTUC,TXOBSITMAF,IDTPEXPITSOL,IDORIGREGISTRO,
               DTGRAVACAO,HRGRAVACAO,DTIMPORTACAO,HRIMPORTACAO, NRSOLTEKNISA,
               CDSOLPORTAL, NRSOLPORTAL, NRITEMSOLPORTAL,
               CDAFPORTAL, NRAFPORTAL, NRITAFPORTAL)
           VALUES
              (V_NOVOCODIGO, V_NRSEQ, C_AFEXPORT.CDFILDEST, C_AFEXPORT.CDFILLANC, C_AFEXPORT.NRAUTOFORN,
               C_ITEMAUTF.CDMARCA, C_ITEMAUTF.CDARVPROD, C_ITEMAUTF.DTPROGENTAF, C_ITEMAUTF.NMPRODUTO, C_ITEMAUTF.VRQTDEAF, C_ITEMAUTF.VRPRECOUNIT,
               (C_ITEMAUTF.VRQTDEAF*C_ITEMAUTF.VRPRECOUNIT), V_VRIVAMP, V_VRIMPINT02, V_VRPIBBA, V_VRPERCIVA,
               V_VRABASTOS, V_VRPIBCP, V_VRPIBCBA, V_VRPIBSFE, V_VRPIBMZA, V_VRPIBSJ, V_VRPIBCAT,
               V_VRPIBTUC, V_VRPIBCTE, V_VRPIBSAL, V_VRPIBSL, V_VRPIBTF, V_VRIVAOC, V_VRIVA19, V_VRIVA20,
               V_VRIMPINT21, V_VRPIBMIS, V_VRPIIBBTUC, C_ITEMAUTF.TXOBSITMAF, '1', 'T',
               NULL, NULL, NULL, NULL,
               V_NRSOLTEKNISA, V_CDSOLPORTAL, V_NRSOLPORTAL, V_NRITEMSOLPORTAL,
               C_ITEMAUTF.USR_CDAFPORTAL, C_ITEMAUTF.USR_NRAFPORTAL, C_ITEMAUTF.USR_NRITAFPORTAL);

           FOR C_IMPOSTO IN
              (SELECT CDIMPOSTO, VRIMPITMAF,VRALIQITMAF
                FROM IMPITMAF
               WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
                 AND CDFILLANC = C_AFEXPORT.CDFILLANC
                 AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
                 AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
                 AND CDMARCA = C_ITEMAUTF.CDMARCA
                 AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF)
           LOOP
              INSERT INTO USR_INT_IMPITMAF(NRSEQUENCIAL, NRSEQITEM, CDFILIAL, CDIMPOSTO, VRALIQUOTA, VRIMPOSTO)
              VALUES (V_NOVOCODIGO, V_NRSEQ, C_AFEXPORT.CDFILDEST, C_IMPOSTO.CDIMPOSTO, C_IMPOSTO.VRALIQITMAF, C_IMPOSTO.VRIMPITMAF);
           END LOOP;
           V_NRSEQ := LPAD(RTRIM(TO_CHAR(TO_NUMBER(RTRIM(V_NRSEQ))+ 1)),4,'0');
        END LOOP;

        UPDATE USR_INT_ITEMAUTF
           SET DTGRAVACAO = V_DTGRV,
               HRGRAVACAO = V_HRGRV
         WHERE NRSEQUENCIAL = V_NOVOCODIGO;

        UPDATE USR_INT_AUTOFORNE
           SET DTGRAVACAO = V_DTGRV,
               HRGRAVACAO = V_HRGRV
         WHERE NRSEQUENCIAL = V_NOVOCODIGO;

        IF C_AFEXPORT.IDMOTIVOENVIO <> '4' THEN
           UPDATE AUTOFORNE
              SET USR_DTEXPORTA = SYSDATE,
                  USR_NRSEQUENCIAL = V_NOVOCODIGO,
                  IDBAIXAAF = '6'
            WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
              AND CDFILLANC = C_AFEXPORT.CDFILLANC
              AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN;
        ELSE
           UPDATE AUTOFORNE
              SET USR_DTEXPORTA = SYSDATE,
                  USR_NRSEQUENCIAL = V_NOVOCODIGO
            WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
              AND CDFILLANC = C_AFEXPORT.CDFILLANC
              AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN;
        END IF;

        V_NRSEQ := '0001';
      END LOOP;
      COMMIT;
      V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_AUTOFORNE%USR_INT_ITEMAUTF', 'D');
   END IF;
EXCEPTION
  WHEN OTHERS THEN BEGIN
     IF V_RETURN = 'S' THEN
        V_ERROR:= SQLERRM(SQLCODE);
        V_RETURN := USR_FUNC_BLOQUEIO('USR_INT_AUTOFORNE%USR_INT_ITEMAUTF', 'D', V_ERROR);
     END IF;
  END;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXPORTAAF','5.70.XXX'); END;
/